#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ncurses.h>

#include "include/main.h"
#include "include/card.h"

void die(char *s) {
    fprintf(stderr, "fatal: %s\n", s);
    exit(1);
}
char *fgetl(FILE *stream) { size_t s_sz = 1; // +1 for null byte
    char *s = NULL;
    char c;

    while ((c = fgetc(stream)) != '\n') {
        if (c == EOF)
            return NULL;

        s = (char *)realloc((void *)s, ++s_sz);
        s[s_sz - 2] = c;
    }

    if (s != NULL)
        s[s_sz - 1] = '\0';

    return s;
}

char *strdup_(char *s) {
    char *r;
    r = (char *)malloc(strlen(s) + 1);
    strcpy(r, s);
    return r;
}

int main(int argc, char **argv) {
    CARD *cards;
    WINDOW *main_card;
    int cards_ct, cc = 0, cf = 0, term_y, term_x;
    char k = '\0';

    if (argc < 2)
        die("filename required");

    cards = card_parse_csv(argv[1], &cards_ct);

    initscr();
    noecho();
    curs_set(0);
    getmaxyx(stdscr, term_y, term_x);
    main_card = newwin(term_y * .75,
            term_x * .75,
            (term_y * .5) - ((term_y * .75) * .5),
            (term_x * .5) - ((term_x * .75) * .5));
    refresh();
    do {
        switch (k) {
            case 'j':
                if (++cc > cards_ct - 1)
                    cc = 0;
                cf = 0;
            break;
            case 'k':
                if (--cc < 0)
                    cc = cards_ct - 1;
                cf = 0;
            break;
            case ' ':
                switch (cf) {
                    case 0: cf = 1; break;
                    case 1: cf = 0; break;
                }
            break;
            case 'q':
                endwin();
                exit(0);
            break;
        }

        wclear(main_card);
        wrefresh(main_card);
        box(main_card, 0, 0);
        if (cf == 0) {
            mvwprintw(main_card, 0, 10, "  Card #%d/%d [front]  \r", cc + 1, cards_ct);
            mvwprintw(main_card, (term_y * .75) * .5, (term_x * .75) * .5, "%s\r", cards[cc].obverse);
        } else {
            mvwprintw(main_card, 0, 10, "  Card #%d/%d [back]  \r", cc + 1, cards_ct);
            mvwprintw(main_card, (term_y * .75) * .5, (term_x * .75) * .5, "%s\r", cards[cc].reverse);
        }
        wrefresh(main_card);
    } while ((k = getch()) != EOF);

    /* for (size_t i = 0; i < cards_ct; i++) */
    /*     printf("o: `%s`, r: `%s`\n", cards[i].obverse, cards[i].reverse); */

    return 0;
}
